import * as React from "react";
import { Dispatch, SetStateAction } from "react";
/**
 * A Toolbar is typically used in something like the Navbar component.
 * It provides some basic horizontal padding and maintains responsive height.
 */
interface MainMenuBarProps extends React.HTMLAttributes<HTMLDivElement> {
    children: React.ReactNode;
}
/**主菜单: <div>高度不会突破限制，长度方向可能突破限制。
 * 安排在网页最下方的位置就不能用position: sticky设置。若position: absolute;会按视窗定位但是滚动就会滚没掉。
 * : sticky 若top没计算准确的可能须滚动到最底下才会有：不精确。
 * 融合掉 <Navbar />
 *CSS在基础组件库配置的   default: `@media (min-width: 320px) and (max-width: 628px)`,
 *                     md: `@media (min-width: ${points.md})`,    配置库目前的md: "629px",超过>=629的才能算true!
 *依据这个设置，我这里正方形的窗体控制，高度 && 宽度同时达到了较大的标准，有任何一个不达标的就只能紧凑CSS模式。
* */
export declare const MainMenuBar: React.FunctionComponent<MainMenuBarProps>;
/**留出菜单临空区域,尺寸等依赖逻辑；
 * noRight  当前URL路由页面没有用右半边的明细页面,
 * rightBig  当前状态把右半边的明细页面放大为整个视口。
 * 通用的CSS切换点， [theme.mediaQueries.md]: { } 配置库目前的 md : "629px"=宽度方向的>=629触发选中该对象;
 * 【毛病】useMedia的局限性？ carousel必须在第二次render才能切换为最终的值，会导致重绘。
 * */
export declare const useMMenuBarOcup: (noRight: boolean) => {
    bottomCss: import("@emotion/utils").SerializedStyles;
    isWideSrc: boolean;
    isBigSrc: boolean;
    barHeight: string;
    carousel: boolean;
    touchScr: boolean;
    mobileList: boolean;
};
export interface PanelEnlargeCtxType {
    enlarge: number;
    setEnlarge: Dispatch<SetStateAction<number>>;
    setActivecas: (i: number) => void;
    getActivecas?: () => number;
}
/**应该放在<TwoHalfFrame>的头上引入。 TwoHalfFrame下面右半边页面必须<TwoHalfRightPanel>包裹的。
 * 右半边详细操作页面被放大为整个视口的页面，放大
 * 跨越多层次的APP路由器页面。
 * */
export declare const PanelEnlargeCtx: React.Context<PanelEnlargeCtxType>;
export {};
