import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import * as React from "react";
import { animated, useTransition } from "@react-spring/web";
import { Portal } from "./Portal";
import { useHideBody } from "./Hooks/hide-body";
import PropTypes from "prop-types";
import { useTheme } from "./Theme/Providers";
/**【淘汰中】 目前 Overlay 只在Dialog一处中才用了：
 *上层组件Dialog 用参数style={{display: 'flex', alignItems: 'center'}}传进来控制大小和居中。
 * */
export const Overlay = React.forwardRef(({ isOpen, onRequestClose, style: divStyle, children }, ref) => {
    const theme = useTheme();
    const transitions = useTransition(isOpen, {
        from: { opacity: 0 },
        enter: { opacity: 1 },
        leave: { opacity: 0 }
    });
    const { bind } = useHideBody(isOpen);
    //console.log("Overlay进入 3 divStyle=", divStyle);
    return (_jsx(Portal, { children: transitions((style, item) => {
            return (item && _jsxs("div", { className: "Overlay_top", ref: ref, ...bind, onClick: (e) => {
                    e.stopPropagation();
                    onRequestClose();
                }, onKeyDown: (e) => {
                    if (e.key === "Escape") {
                        e.stopPropagation();
                        onRequestClose();
                    }
                }, css: [
                    {
                        bottom: 0,
                        left: 0,
                        overflow: "auto",
                        width: "100%",
                        height: "100%",
                        zIndex: theme.zIndices.overlay,
                        position: "fixed",
                        content: "''",
                        right: 0,
                        top: 0,
                        WebkitTapHighlightColor: "transparent",
                        //display: "block",
                    },
                    { ...divStyle },
                ], children: [_jsx(animated.div, { style: { opacity: style.opacity }, css: [
                            {
                                //对话框超出屏幕的高度了，无法遮盖滚动后的背景，position: "absolute",
                                position: "fixed",
                                top: 0,
                                left: 0,
                                right: 0,
                                bottom: 0,
                                background: theme.colors.background.overlay,
                                //display: "block",
                            }
                        ] }), children] }, 1));
        }) }));
});
Overlay.displayName = "Overlay";
Overlay.propTypes = {
    isOpen: PropTypes.bool.isRequired,
    onRequestClose: PropTypes.func.isRequired,
    children: PropTypes.node
};
//# sourceMappingURL=Overlay.js.map